@@ -37,8 +37,8 @@
 #ifndef EEL_CANVAS_H
 #define EEL_CANVAS_H
 
-#include <gtk/gtklayout.h>
-#include <gdk/gdkevents.h>
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include <stdarg.h>
 
 G_BEGIN_DECLS
@@ -110,7 +110,7 @@ enum {
 
 
 struct _EelCanvasItem {
-	GtkObject object;
+	GInitiallyUnowned object;
 
 	/* Parent canvas for this item */
 	EelCanvas *canvas;
@@ -120,10 +120,15 @@ struct _EelCanvasItem {
 
 	/* Bounding box for this item (in canvas coordinates) */
 	double x1, y1, x2, y2;
+
+	/* Object flags */
+	guint flags;
 };
 
 struct _EelCanvasItemClass {
-	GtkObjectClass parent_class;
+	GInitiallyUnownedClass parent_class;
+
+	void (* destroy) (EelCanvasItem *item);
 
 	/* Tell the item to update itself.  The flags are from the update flags
 	 * defined above.  The item should update its internal state from its
@@ -148,7 +153,7 @@ struct _EelCanvasItemClass {
 	 * coordinates of the drawable, a temporary pixmap, where things get
 	 * drawn.  (width, height) are the dimensions of the drawable.
 	 */
-	void (* draw) (EelCanvasItem *item, GdkDrawable *drawable, GdkEventExpose *expose);
+	void (* draw) (EelCanvasItem *item, cairo_t *cr, cairo_region_t *region);
 
 	/* Calculate the distance from an item to the specified point.  It also
          * returns a canvas item which is the item itself in the case of the
@@ -186,6 +191,8 @@ GType eel_canvas_item_get_type (void) G_GNUC_CONST;
 EelCanvasItem *eel_canvas_item_new (EelCanvasGroup *parent, GType type,
 				    const gchar *first_arg_name, ...);
 
+void eel_canvas_item_destroy (EelCanvasItem *item);
+
 /* Constructors for use in derived classes and language wrappers */
 void eel_canvas_item_construct (EelCanvasItem *item, EelCanvasGroup *parent,
 				const gchar *first_arg_name, va_list args);
@@ -238,8 +245,10 @@ void eel_canvas_item_hide (EelCanvasItem *item);
  * grab.  Time is a proper X event time parameter.  Returns the same values as
  * XGrabPointer().
  */
-int eel_canvas_item_grab (EelCanvasItem *item, unsigned int event_mask,
-			  GdkCursor *cursor, guint32 etime);
+GdkGrabStatus eel_canvas_item_grab (EelCanvasItem *item,
+				    GdkEventMask event_mask,
+				    GdkCursor *cursor,
+				    guint32 etime);
 
 /* Ungrabs the mouse -- the specified item must be the same that was passed to
  * eel_canvas_item_grab().  Time is a proper X event time parameter.
@@ -360,9 +369,6 @@ struct _EelCanvas {
 	/* If non-NULL, the currently focused item */
 	EelCanvasItem *focused_item;
 
-	/* GC for temporary draw pixmap */
-	GdkGC *pixmap_gc;
-
 	/* Event on which selection of current item is based */
 	GdkEvent pick_event;
 
@@ -420,7 +426,7 @@ struct _EelCanvasClass {
 	/* Draw the background for the area given.
 	 */
 	void (* draw_background) (EelCanvas *canvas,
-				  int x, int y, int width, int height);
+                                  cairo_t *cr);
 
 	/* Private Virtual methods for groping the canvas inside bonobo */
 	void (* request_update) (EelCanvas *canvas);
@@ -508,23 +514,6 @@ void eel_canvas_window_to_world (EelCanvas *canvas,
 void eel_canvas_world_to_window (EelCanvas *canvas,
 				 double worldx, double worldy, double *winx, double *winy);
 
-/* Takes a string specification for a color and allocates it into the specified
- * GdkColor.  If the string is null, then it returns FALSE. Otherwise, it
- * returns TRUE.
- */
-int eel_canvas_get_color (EelCanvas *canvas, const char *spec, GdkColor *color);
-
-/* Allocates a color from the RGB value passed into this function. */
-gulong eel_canvas_get_color_pixel (EelCanvas *canvas,
-				   guint        rgba);
-     
-
-/* Sets the stipple origin of the specified gc so that it will be aligned with
- * all the stipples used in the specified canvas.  This is intended for use only
- * by canvas item implementations.
- */
-void eel_canvas_set_stipple_origin (EelCanvas *canvas, GdkGC *gc);
-
 G_END_DECLS
 
 #endif
