@@ -53,7 +53,6 @@
 #define LABEL_LINE_SPACING 0
 
 #define MAX_TEXT_WIDTH_STANDARD 135
-#define MAX_TEXT_WIDTH_TIGHTER 80
 #define MAX_TEXT_WIDTH_BESIDE 90
 #define MAX_TEXT_WIDTH_BESIDE_TOP_TO_BOTTOM 150
 
@@ -143,6 +142,8 @@ struct NautilusIconCanvasItemDetails {
 	EelIRect bounds_cache_for_layout;
 	EelIRect bounds_cache_for_entire_item;
 
+	GdkWindow *cursor_window;
+
 	/* Accessibility bits */
 	GailTextUtil *text_util;
 };
@@ -220,6 +221,11 @@ nautilus_icon_canvas_item_finalize (GObject *object)
 
 	details = NAUTILUS_ICON_CANVAS_ITEM (object)->details;
 
+	if (details->cursor_window != NULL) {
+		gdk_window_set_cursor (details->cursor_window, NULL);
+		g_object_unref (details->cursor_window);
+	}
+
 	if (details->pixbuf != NULL) {
 		g_object_unref (details->pixbuf);
 	}
@@ -1149,15 +1155,7 @@ draw_label_text (NautilusIconCanvasItem *item,
 				      "activate_prelight_icon_label", &prelight_label,
 				      NULL);
 		if (!needs_highlight && details->text_width > 0 && details->text_height > 0) {
-			if (!(prelight_label && item->details->is_prelit)) {
-				draw_frame (item, 
-					    cr,
-					    &container->details->normal_color_rgba,
-					    text_rect.x0,
-					    text_rect.y0,
-					    text_rect.x1 - text_rect.x0,
-					    text_rect.y1 - text_rect.y0);
-			} else {
+			if (prelight_label && item->details->is_prelit) {
 				draw_frame (item, 
 					    cr,
 					    &container->details->prelight_color_rgba,
@@ -1676,8 +1674,10 @@ nautilus_icon_canvas_item_event (EelCanvasItem *item, GdkEvent *event)
 {
 	NautilusIconCanvasItem *icon_item;
 	GdkCursor *cursor;
+	GdkWindow *cursor_window;
 
 	icon_item = NAUTILUS_ICON_CANVAS_ITEM (item);
+	cursor_window = ((GdkEventAny *)event)->window;
 
 	switch (event->type) {
 	case GDK_ENTER_NOTIFY:
@@ -1692,8 +1692,10 @@ nautilus_icon_canvas_item_event (EelCanvasItem *item, GdkEvent *event)
 			if (in_single_click_mode ()) {
 				cursor = gdk_cursor_new_for_display (gdk_display_get_default(),
 								     GDK_HAND2);
-				gdk_window_set_cursor (((GdkEventAny *)event)->window, cursor);
+				gdk_window_set_cursor (cursor_window, cursor);
 				g_object_unref (cursor);
+
+				icon_item->details->cursor_window = g_object_ref (cursor_window);
 			}
 
 			/* FIXME bugzilla.gnome.org 42473: 
@@ -1739,7 +1741,8 @@ nautilus_icon_canvas_item_event (EelCanvasItem *item, GdkEvent *event)
 			eel_canvas_item_request_update (item);
 
 			/* show default cursor */
-			gdk_window_set_cursor (((GdkEventAny *)event)->window, NULL);
+			gdk_window_set_cursor (cursor_window, NULL);
+			g_clear_object (&icon_item->details->cursor_window);
 		}
 		return TRUE;
 		
@@ -2176,28 +2179,20 @@ nautilus_icon_canvas_item_get_max_text_width (NautilusIconCanvasItem *item)
 	canvas_item = EEL_CANVAS_ITEM (item);
 	container = NAUTILUS_ICON_CONTAINER (canvas_item->canvas);
 
-	if (nautilus_icon_container_is_tighter_layout (container)) {
-		return MAX_TEXT_WIDTH_TIGHTER * canvas_item->canvas->pixels_per_unit;
-	} else {
-				
-                if (container->details->label_position == NAUTILUS_ICON_LABEL_POSITION_BESIDE) {
-			if (container->details->layout_mode == NAUTILUS_ICON_LAYOUT_T_B_L_R ||
-			    container->details->layout_mode == NAUTILUS_ICON_LAYOUT_T_B_R_L) {
-				if (container->details->all_columns_same_width) {
-					return MAX_TEXT_WIDTH_BESIDE_TOP_TO_BOTTOM * canvas_item->canvas->pixels_per_unit;
-				} else {
-					return -1;
-				}
+	if (container->details->label_position == NAUTILUS_ICON_LABEL_POSITION_BESIDE) {
+		if (container->details->layout_mode == NAUTILUS_ICON_LAYOUT_T_B_L_R ||
+		    container->details->layout_mode == NAUTILUS_ICON_LAYOUT_T_B_R_L) {
+			if (container->details->all_columns_same_width) {
+				return MAX_TEXT_WIDTH_BESIDE_TOP_TO_BOTTOM * canvas_item->canvas->pixels_per_unit;
 			} else {
-				return MAX_TEXT_WIDTH_BESIDE * canvas_item->canvas->pixels_per_unit;
+				return -1;
 			}
-                } else {
-			return MAX_TEXT_WIDTH_STANDARD * canvas_item->canvas->pixels_per_unit;
-                }
-
-
+		} else {
+			return MAX_TEXT_WIDTH_BESIDE * canvas_item->canvas->pixels_per_unit;
+		}
+	} else {
+		return MAX_TEXT_WIDTH_STANDARD * canvas_item->canvas->pixels_per_unit;
 	}
-
 }
 
 void
