@@ -97,12 +97,9 @@ search_directory_file_get_item_count (NautilusFile *file,
 				      guint *count,
 				      gboolean *count_unreadable)
 {
-	NautilusSearchDirectory *search_dir;
 	GList *file_list;
 
 	if (count) {
-		search_dir = NAUTILUS_SEARCH_DIRECTORY (file->details->directory);
-
 		file_list = nautilus_directory_get_file_list (file->details->directory);
 
 		*count = g_list_length (file_list);
@@ -120,14 +117,11 @@ search_directory_file_get_deep_counts (NautilusFile *file,
 				       guint *unreadable_directory_count,
 				       goffset *total_size)
 {
-	NautilusSearchDirectory *search_dir;
 	NautilusFile *dir_file;
 	GList *file_list, *l;
 	guint dirs, files;
 	GFileType type;
 
-	search_dir = NAUTILUS_SEARCH_DIRECTORY (file->details->directory);
-	
 	file_list = nautilus_directory_get_file_list (file->details->directory);
 
 	dirs = files = 0;
@@ -192,7 +186,7 @@ nautilus_search_directory_file_update_display_name (NautilusSearchDirectoryFile
 		display_name = g_strdup (_("Search"));
 	}
 
-	changed = nautilus_file_set_display_name (file, display_name, NULL, FALSE);
+	changed = nautilus_file_set_display_name (file, display_name, NULL, TRUE);
 	if (changed) {
 		nautilus_file_emit_changed (file);
 	}
@@ -213,7 +207,7 @@ nautilus_search_directory_file_init (NautilusSearchDirectoryFile *search_file)
 	file->details->file_info_is_up_to_date = TRUE;
 
 	file->details->custom_icon = NULL;
-	file->details->activation_location = NULL;
+	file->details->activation_uri = NULL;
 	file->details->got_link_info = TRUE;
 	file->details->link_info_is_up_to_date = TRUE;
 
@@ -221,16 +215,14 @@ nautilus_search_directory_file_init (NautilusSearchDirectoryFile *search_file)
 	file->details->got_directory_count = TRUE;
 	file->details->directory_count_is_up_to_date = TRUE;
 
-	nautilus_file_set_display_name (file, _("Search"), NULL, FALSE);
+	nautilus_file_set_display_name (file, _("Search"), NULL, TRUE);
 }
 
 static void
 nautilus_search_directory_file_class_init (NautilusSearchDirectoryFileClass *klass)
 {
-	GObjectClass *object_class;
 	NautilusFileClass *file_class;
 
-	object_class = G_OBJECT_CLASS (klass);
 	file_class = NAUTILUS_FILE_CLASS (klass);
 
 	file_class->default_file_type = G_FILE_TYPE_DIRECTORY;
