@@ -905,8 +905,6 @@ nautilus_application_command_line (GApplication *app,
 	gboolean no_default_window = FALSE;
 	gboolean no_desktop = FALSE;
 	gboolean kill_shell = FALSE;
-	gboolean autostart_mode = FALSE;
-	const gchar *autostart_id;
 	gchar *geometry = NULL;
 	gchar **remaining = NULL;
 	const GOptionEntry options[] = {
@@ -941,11 +939,6 @@ nautilus_application_command_line (GApplication *app,
 
 	argv = g_application_command_line_get_arguments (command_line, &argc);
 
-	autostart_id = g_getenv ("DESKTOP_AUTOSTART_ID");
-	if (autostart_id != NULL && *autostart_id != '\0') {
-		autostart_mode = TRUE;
-        }
-
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
 		g_printerr ("Could not parse arguments: %s\n", error->message);
 		g_error_free (error);
@@ -1004,14 +997,6 @@ nautilus_application_command_line (GApplication *app,
 		goto out;
 	}
 
-	/* If in autostart mode (aka started by gnome-session), we need to ensure 
-         * nautilus starts with the correct options.
-         */
-	if (autostart_mode) {
-		no_default_window = TRUE;
-		no_desktop = FALSE;
-	}
-
 	DEBUG ("Parsing command line, no_default_window %d, quit %d, "
 	       "self checks %d, no_desktop %d",
 	       no_default_window, kill_shell, perform_self_check, no_desktop);
