@@ -31,7 +31,6 @@
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
-#include "nautilus-application.h"
 #include "nautilus-bookmark-list.h"
 #include "nautilus-connect-server-operation.h"
 #include "nautilus-window.h"
@@ -45,8 +44,6 @@
  */
 
 struct _NautilusConnectServerDialogDetails {
-	NautilusApplication *application;
-
 	GtkWidget *primary_table;
 	GtkWidget *user_details;
 	GtkWidget *port_spinbutton;
@@ -380,14 +377,13 @@ connect_dialog_request_additional_details (NautilusConnectServerDialog *self,
 					   const gchar *default_user,
 					   const gchar *default_domain)
 {
-	GtkWidget *content_area, *label, *entry, *hbox, *icon;
+	GtkWidget *content_area, *label, *hbox, *icon;
 
 	self->details->fill_details_flags = flags;
 
 	connect_dialog_restore_info_bar (self, GTK_MESSAGE_WARNING);
 
 	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (self->details->info_bar));
-	entry = NULL;
 
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (content_area), hbox, FALSE, FALSE, 6);
@@ -480,8 +476,7 @@ mount_enclosing_ready_cb (GObject *source,
 
 	if (!error || g_error_matches (error, G_IO_ERROR, G_IO_ERROR_ALREADY_MOUNTED)) {
 		/* volume is mounted, show it */
-		nautilus_connect_server_dialog_display_location_async (dialog,
-								       dialog->details->application, location,
+		nautilus_connect_server_dialog_display_location_async (dialog, location,
 								       display_location_async_cb, NULL);
 	} else {
 		if (dialog->details->should_destroy) {
@@ -498,7 +493,6 @@ mount_enclosing_ready_cb (GObject *source,
 
 static void
 connect_dialog_present_uri_async (NautilusConnectServerDialog *self,
-				  NautilusApplication *application,
 				  GFile *location)
 {
 	GMountOperation *op;
@@ -519,6 +513,7 @@ connect_dialog_connect_to_server (NautilusConnectServerDialog *dialog)
 	GtkTreeIter iter;
 	char *user, *initial_path, *server, *folder, *domain, *port_str;
 	char *t, *join, *uri;
+	char *temp, *stripped_server;
 	double port;
 
 	/* Get our method info */
@@ -530,6 +525,14 @@ connect_dialog_connect_to_server (NautilusConnectServerDialog *dialog)
 
 	server = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->server_entry), 0, -1);
 
+	temp = g_strconcat (meth->scheme, "://", NULL);
+	if (g_str_has_prefix (server, temp)) {
+		stripped_server = g_strdup (server + strlen (temp));
+		g_free (server);
+		server = stripped_server;
+	}
+	g_free (temp);
+
 	user = NULL;
 	initial_path = g_strdup ("");
 	domain = NULL;
@@ -615,7 +618,6 @@ connect_dialog_connect_to_server (NautilusConnectServerDialog *dialog)
 
 	connect_dialog_set_connecting (dialog);
 	connect_dialog_present_uri_async (dialog,
-					  dialog->details->application,
 					  location);
 
 	g_object_unref (location);
@@ -681,7 +683,7 @@ connect_dialog_response_cb (NautilusConnectServerDialog *dialog,
 	case GTK_RESPONSE_HELP :
 		error = NULL;
 		gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (dialog)),
-			      "ghelp:user-guide#nautilus-server-connect",
+			      "ghelp:gnome-help#nautilus-connect",
 			      gtk_get_current_event_time (), &error);
 		if (error) {
 			eel_show_error_dialog (_("There was an error displaying help."), error->message,
@@ -908,7 +910,7 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 	gtk_widget_show (dialog->details->port_spinbutton);
 
 	/* second row: type combobox */
-	label = gtk_label_new (_("Type:"));
+	label = gtk_label_new_with_mnemonic (_("_Type:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1,
@@ -919,6 +921,7 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 
 	dialog->details->type_combo = combo = gtk_combo_box_new ();
 	gtk_size_group_add_widget (dialog->details->contents_size_group, dialog->details->type_combo);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->details->type_combo);
 
 	/* each row contains: method index, textual description */
 	store = gtk_list_store_new (2, G_TYPE_INT, G_TYPE_STRING);
@@ -981,7 +984,7 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 				  dialog);
 
 	/* third row: share entry */
-	label = gtk_label_new (_("Share:"));
+	label = gtk_label_new_with_mnemonic (_("Sh_are:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1,
@@ -996,17 +999,19 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 			  2, 3,
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 6, 3);
 	gtk_size_group_add_widget (dialog->details->contents_size_group, dialog->details->share_entry);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->details->share_entry);
 
 	bind_visibility (dialog, dialog->details->share_entry, label);
 
 	/* fourth row: folder entry */
-	label = gtk_label_new (_("Folder:"));
+	label = gtk_label_new_with_mnemonic (_("_Folder:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1,
 			  3, 4,
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 6, 3);
 	gtk_size_group_add_widget (dialog->details->labels_size_group, label);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->details->share_entry);
 	gtk_widget_show (label);
 
 	dialog->details->folder_entry = gtk_entry_new ();
@@ -1018,6 +1023,7 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 6, 3);
 	gtk_size_group_add_widget (dialog->details->contents_size_group, dialog->details->folder_entry);
 	gtk_widget_show (dialog->details->folder_entry);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->details->folder_entry);
 
 	/* user details label */
 	label = gtk_label_new (NULL);
@@ -1041,7 +1047,7 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 	gtk_widget_show (table);
 
 	/* first row: domain entry */
-	label = gtk_label_new (_("Domain Name:"));
+	label = gtk_label_new_with_mnemonic (_("_Domain name:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1,
@@ -1056,11 +1062,11 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 			  0, 1,
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 6, 3);
 	gtk_size_group_add_widget (dialog->details->contents_size_group, dialog->details->domain_entry);
-
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->details->domain_entry);
 	bind_visibility (dialog, dialog->details->domain_entry, label);
 
 	/* second row: username entry */
-	label = gtk_label_new (_("User Name:"));
+	label = gtk_label_new_with_mnemonic (_("_User name:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1,
@@ -1075,11 +1081,12 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 			  1, 2,
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 6, 3);
 	gtk_size_group_add_widget (dialog->details->contents_size_group, dialog->details->user_entry);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->details->user_entry);
 
 	bind_visibility (dialog, dialog->details->user_entry, label);
 
 	/* third row: password entry */
-	label = gtk_label_new (_("Password:"));
+	label = gtk_label_new_with_mnemonic (_("Pass_word:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label,
 			  0, 1,
@@ -1095,11 +1102,12 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 			  2, 3,
 			  GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 6, 3);
 	gtk_size_group_add_widget (dialog->details->contents_size_group, dialog->details->password_entry);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), dialog->details->password_entry);
 
 	bind_visibility (dialog, dialog->details->password_entry, label);
 
 	/* fourth row: remember checkbox */
-	checkbox = gtk_check_button_new_with_label (_("Remember this password"));
+	checkbox = gtk_check_button_new_with_mnemonic (_("_Remember this password"));
 	gtk_table_attach (GTK_TABLE (table), checkbox,
 			  1, 2,
 			  3, 4,
@@ -1165,16 +1173,13 @@ nautilus_connect_server_dialog_class_init (NautilusConnectServerDialogClass *cla
 GtkWidget *
 nautilus_connect_server_dialog_new (NautilusWindow *window)
 {
-	NautilusConnectServerDialog *conndlg;
 	GtkWidget *dialog;
 
 	dialog = gtk_widget_new (NAUTILUS_TYPE_CONNECT_SERVER_DIALOG, NULL);
-	conndlg = NAUTILUS_CONNECT_SERVER_DIALOG (dialog);
 
 	if (window) {
 		gtk_window_set_screen (GTK_WINDOW (dialog),
 				       gtk_window_get_screen (GTK_WINDOW (window)));
-		conndlg->details->application = window->application;
 	}
 
 	return dialog;
