@@ -198,6 +198,7 @@ static void                 preview_audio                             (NautilusI
 static void                 update_layout_menus                       (NautilusIconView     *view);
 static NautilusFileSortType get_default_sort_order                    (NautilusFile         *file,
 								       gboolean             *reversed);
+static void                 nautilus_icon_view_clear                  (NautilusView         *view);
 
 G_DEFINE_TYPE (NautilusIconView, nautilus_icon_view, NAUTILUS_TYPE_VIEW);
 
@@ -208,6 +209,8 @@ nautilus_icon_view_destroy (GtkWidget *object)
 
 	icon_view = NAUTILUS_ICON_VIEW (object);
 
+	nautilus_icon_view_clear (NAUTILUS_VIEW (object));
+
         if (icon_view->details->react_to_icon_change_idle_id != 0) {
                 g_source_remove (icon_view->details->react_to_icon_change_idle_id);
 		icon_view->details->react_to_icon_change_idle_id = 0;
@@ -1917,7 +1920,7 @@ preview_audio (NautilusIconView *icon_view, NautilusFile *file, gboolean start_f
 			
 	if (start_flag) {
 		icon_view->details->audio_preview_file = file;
-		icon_view->details->audio_preview_timeout = g_timeout_add_seconds (1, play_file, icon_view);
+		icon_view->details->audio_preview_timeout = g_timeout_add (1000, play_file, icon_view);
 	}
 }
 
@@ -2016,7 +2019,7 @@ icon_container_preview_callback (NautilusIconContainer *container,
 			g_free (file_name);
 			nautilus_window_slot_set_status
 				(nautilus_view_get_nautilus_window_slot (NAUTILUS_VIEW (icon_view)),
-				 message);
+				 message, NULL);
 			g_free (message);
 		} else {
 			nautilus_view_display_selection_info (NAUTILUS_VIEW(icon_view));
@@ -2541,10 +2544,11 @@ static NautilusIconContainer *
 create_icon_container (NautilusIconView *icon_view)
 {
 	NautilusIconContainer *icon_container;
-	GtkWidget *overlay;
 
 	icon_container = nautilus_icon_view_container_new (icon_view);
 	icon_view->details->icon_container = GTK_WIDGET (icon_container);
+	g_object_add_weak_pointer (G_OBJECT (icon_container),
+				   (gpointer *) &icon_view->details->icon_container);
 	
 	gtk_widget_set_can_focus (GTK_WIDGET (icon_container), TRUE);
 	
@@ -2599,10 +2603,8 @@ create_icon_container (NautilusIconView *icon_view)
 	g_signal_connect_object (icon_container, "store_layout_timestamp",
 				 G_CALLBACK (store_layout_timestamp), icon_view, 0);
 
-	overlay = gedit_overlay_new (GTK_WIDGET (icon_container));
-	gtk_widget_show (overlay);
-
-	nautilus_view_setup_overlay (NAUTILUS_VIEW (icon_view), overlay);
+	gtk_container_add (GTK_CONTAINER (icon_view),
+			   GTK_WIDGET (icon_container));
 
 	nautilus_icon_view_update_click_mode (icon_view);
 
